Key

Enum Key 

#[non_exhaustive]
pub enum Key {
Show 21 variants Char(char), F(u8), Backspace, Enter, Left, Right, Up, Down, Tab, Delete, Home, End, PageUp, PageDown, Esc, Copy, Cut, Paste, MouseScrollDown, MouseScrollUp, Null,
}
Backend-agnostic key input kind.

This type is marked as #[non_exhaustive] since more keys may be supported in the future.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Char(char)

Normal letter key input



F(u8)

F1, F2, F3, … keys



Backspace

Backspace key



Enter

Enter or return key



Left

Left arrow key



Right

Right arrow key



Up

Up arrow key



Down

Down arrow key



Tab

Tab key



Delete

Delete key



Home

Home key



End

End key



PageUp

Page up key



PageDown

Page down key



Esc

Escape key



Copy

Copy key. This key is supported by termwiz only



Cut

Cut key. This key is supported by termwiz only



Paste

Paste key. This key is supported by termwiz only



MouseScrollDown

Virtual key to scroll down by mouse



MouseScrollUp

Virtual key to scroll up by mouse



Null

An invalid key input (this key is always ignored by TextArea)